@@ -1,16 +1,16 @@
 //! Represents the schedule of a single event in a maps' [meta]
 
-use std::{fmt::Display, ops::Add};
+use std::{fmt::Debug, ops::Add};
 
 use chrono::{Duration, NaiveTime, Timelike};
 
 use crate::event::EventInstance;
 
 /// The schedule of a map meta event
-#[derive(Clone, Debug)]
+#[derive(Clone)]
 pub struct EventSchedule {
     /// The name of the event
-    pub name: String,
+    pub name: &'static str,
 
     /// The offset from UTC 00:00 the first event occurs
     pub offset: NaiveTime,
@@ -31,7 +31,7 @@ impl<'a> IntoIterator for &'a EventSchedule {
     }
 }
 
-impl Display for EventSchedule {
+impl Debug for EventSchedule {
     fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
         write!(
             f,
@@ -118,13 +118,11 @@ impl<'a> Iterator for IntoIter<'a> {
             offset + freq
         };
 
-        let offset = Duration::minutes(offset + i * freq);
-
-        self.offset = offset;
+        self.offset = Duration::minutes(offset + i * freq);
 
         Some(EventInstance {
             schedule: self.event_schedule.clone(),
-            start_time: offset,
+            start_time: self.offset,
         })
     }
 }
